# Selfbotdiscord

Selfbotdiscord is a Python library for hat sends friend requests, sends messages, deletes messages, and shows you your message logs from your own account with dic!

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install selfbotdiscord.

```bash
pip install selfbotdiscord
```

## Usage
Go to [discord offical website](https://discord.com/register) and create a new account                 
                             After then enter the application part, put it in phone mode and copy the bottom token part without ""
## Contributing
To contribute to me, you can reach me via eemrovsky@gmail.com and tell me your ideas.

##Detailed documentation
You can read [selfbotdiscord's readthedocs](https://selfbotdiscord.readthedocs.io/en/latest/usage/usage.html)

## License
[MIT](https://choosealicense.com/licenses/mit/)